@@ -1,22 +1,67 @@
 ;;; romkan.el --- Romaji/Kana conversion library -*- lexical-binding: t; -*-
 ;;
-;; Copyright (C) 2023 gicrisf
+;; Copyright (C) 2023, 2025 Giovanni Crisalfi
+;; Copyright (C) 2012, 2013 Mort Yao
+;; Copyright (C) 2010 Masato Hagiwara
+;; Copyright (C) 2001 Satoru Takabayashi
 ;;
 ;; Author: gicrisf <giovanni.crisalfi@protonmail.com>
 ;; Maintainer: gicrisf <giovanni.crisalfi@protonmail.com>
-;; Created: luglio 21, 2023
-;; Modified: luglio 24, 2023
-;; Package-Version: 1.0.0
-;; Package-Revision: v1.0.0-0-g98f41dfd8383
+;; Created: July 21, 2023
+;; Modified: August 14, 2025
+;; Package-Version: 20251019.1646
+;; Package-Revision: 81cf9448450b
 ;; Keywords: i18n languages
-;; Homepage: https://github.com/cromo/romkan
+;; Homepage: https://github.com/gicrisf/romkan.el
 ;; Package-Requires: ((emacs "24.3"))
+;; SPDX-License-Identifier: BSD-3-Clause
 ;;
 ;; This file is not part of GNU Emacs.
 ;;
+;; Redistribution and use in source and binary forms, with or without
+;; modification, are permitted provided that the following conditions are met:
+;;
+;; 1. Redistributions of source code must retain the above copyright notice,
+;;    this list of conditions and the following disclaimer.
+;;
+;; 2. Redistributions in binary form must reproduce the above copyright notice,
+;;    this list of conditions and the following disclaimer in the documentation
+;;    and/or other materials provided with the distribution.
+;;
+;; 3. Neither the name of the copyright holders nor the names of its
+;;    contributors may be used to endorse or promote products derived from this
+;;    software without specific prior written permission.
+;;
+;; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+;; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+;; ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
+;; LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+;; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+;; SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+;; INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+;; CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+;; ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+;; POSSIBILITY OF SUCH DAMAGE.
+;;
 ;;; Commentary:
 ;;
-;;  Description
+;; romkan.el provides bidirectional conversion between Japanese Romaji
+;; (ローマ字) and Kana (仮名) scripts. It supports both Hiragana (平仮名)
+;; and Katakana (片仮名), as well as conversion between Hepburn
+;; (ヘボン式) and Kunrei-shiki (訓令式) romanization systems.
+;;
+;; Usage:
+;;
+;;   (romkan-to-hiragana "konnichiwa")  ;; => "こんにちわ"
+;;   (romkan-to-katakana "konnichiwa")  ;; => "コンニチワ"
+;;   (romkan-to-roma "こんにちは")       ;; => "konnichiha"
+;;   (romkan-to-hepburn "konnitiha")    ;; => "konnichiha"
+;;   (romkan-to-kunrei "konnichiha")    ;; => "konnitiha"
+;;
+;; The package uses static conversion tables for efficiency and supports
+;; common Romaji patterns including double consonants (っ/ッ), long vowels,
+;; and special characters.
 ;;
 ;;; Code:
 
@@ -1940,33 +1985,25 @@
 
 (defun romkan--remove-apostrophes (str)
   "Remove unnecessary apostrophes in STR."
-  (replace-regexp-in-string (rx "n'" (or (not (or "a" "i" "u" "e" "o" "y" "n")) eol))
-                            (lambda (substr)
-                              (replace-regexp-in-string "'.*" (lambda (subsubstr)
-                                                                (substring subsubstr 1))
-                                                        substr)) str))
+  (replace-regexp-in-string
+   (rx "n'" (or (not (or "a" "i" "u" "e" "o" "y" "n")) eol))
+   (lambda (substr)
+     (replace-regexp-in-string
+      "'.*"
+      (lambda (subsubstr) (substring subsubstr 1))
+      substr))
+   str))
 
 (defun romkan--normalize-double-n (str)
   "Normalize double n in STR."
   (let ((str (replace-regexp-in-string "nn" "n'" str)))
     (romkan--remove-apostrophes str)))
 
-(defun romkan--test-for-normalize-double-n ()
-  "Test the 'romkan--normalize-double-n' function."
-  ;; test tanni
-  (cl-assert (equal "tan'i" (romkan--normalize-double-n "tanni")))
-  ;; test kannji
-  (cl-assert (equal "kanji" (romkan-to-hepburn "kannji")))
-  ;; test hannnou
-  (cl-assert (equal "han'nou" (romkan-to-hepburn "hannnou")))
-  ;; test hannnya
-  (cl-assert (equal "han'nya" (romkan-to-hepburn "hannnya"))))
-
 (defun romkan-to-katakana (str)
   "Convert a Romaji (ローマ字) to a Katakana (片仮名) in STR."
   (let* ((str (downcase str))
          (str (replace-regexp-in-string "nn" "n'" str))
-         (str (replace-regexp-in-string "n'(?=[^aiueoyn]\\|$)" "n" str)))
+         (str (replace-regexp-in-string "n'(?=[^aiueoyn]\\|\\$)" "n" str)))
     (romkan--transliterate romkan-rompat romkan-romkan str)))
 
 (defun romkan--transliterate (regex-matcher alist-dict str)
@@ -1983,7 +2020,7 @@
          (str (romkan--normalize-double-n str)))
     (romkan--transliterate romkan-rompat-h romkan-romkan-h str)))
 
-(defalias 'romkan-to-kana 'romkan-to-katakana)
+(defalias 'romkan-to-kana #'romkan-to-katakana)
 
 (defun romkan-to-roma (str)
   "Convert a Kana (仮名) to a Hepburn Romaji (ヘボン式ローマ字) in STR."
@@ -2016,79 +2053,5 @@ to a Hepburn Romaji (ヘボン式ローマ字) in STR."
                 tmp)))
     (romkan--transliterate romkan-kunpat romkan-to-hepburn tmp)))
 
-(defun romkan--test-for-hiragana ()
-  "Test the 'romkan-to-hiragana' function."
-  ;; test kanji
-  (cl-assert (equal "かんじ" (romkan-to-hiragana "kanji")))
-  ;; test kanzi
-  (cl-assert (equal "かんじ" (romkan-to-hiragana "kanzi")))
-  ;; test kannji
-  (cl-assert (equal "かんじ" (romkan-to-hiragana "kannji")))
-  ;; test chie
-  (cl-assert (equal "ちえ" (romkan-to-hiragana "chie")))
-  ;; test tie
-  (cl-assert (equal "ちえ" (romkan-to-hiragana "tie")))
-  ;; test kyouju
-  (cl-assert (equal "きょうじゅ" (romkan-to-hiragana "kyouju")))
-  ;; test syuukyou
-  (cl-assert (equal "しゅうきょう" (romkan-to-hiragana "syuukyou")))
-  ;; test shuukyou
-  (cl-assert (equal "しゅうきょう" (romkan-to-hiragana "shuukyou")))
-  ;; test saichuu
-  (cl-assert (equal "さいちゅう" (romkan-to-hiragana "saichuu")))
-  ;; test saityuu
-  (cl-assert (equal "さいちゅう" (romkan-to-hiragana "saityuu")))
-  ;; test cheri
-  (cl-assert (equal "ちぇりー" (romkan-to-hiragana "cheri-")))
-  ;; test tyeri
-  (cl-assert (equal "ちぇりー" (romkan-to-hiragana "tyeri-")))
-  ;; test shinrai
-  (cl-assert (equal "しんらい" (romkan-to-hiragana "shinrai")))
-  ;; test sinrai
-  (cl-assert (equal "しんらい" (romkan-to-hiragana "sinrai")))
-  ;; test hannnou
-  (cl-assert (equal "はんのう" (romkan-to-hiragana "hannnou")))
-  ;; test hannou
-  (cl-assert (equal "はんのう" (romkan-to-hiragana "han'nou")))
-  ;; test je
-  (cl-assert (equal "じぇ" (romkan-to-hiragana "je")))
-  ;; test ejento
-  (cl-assert (equal "えーじぇんと" (romkan-to-hiragana "e-jento"))))
-
-(defun romkan--test-for-hepburn ()
-  "Test the 'romkan-to-hepburn' function."
-  ;; test kannzi
-  (cl-assert (equal "kanji" (romkan-to-hepburn "kannzi")))
-  ;; test tie
-  (cl-assert (equal "chie" (romkan-to-hepburn "tie"))))
-
-(defun romkan--test-for-kunrei ()
-  "Test the 'romkan-to-kunrei' function."
-  ;; test kanji
-  (cl-assert (equal "kanzi" (romkan-to-kunrei "kanji")))
-  ;; test chie
-  (cl-assert (equal "tie" (romkan-to-kunrei "chie"))))
-
-(defun romkan--test-for-roma ()
-  "Test the 'romkan-to-roma' function."
-  ;; test かんじ
-  (cl-assert (equal "kanji" (romkan-to-roma "かんじ")))
-  ;; test ちゃう
-  (cl-assert (equal "chau" (romkan-to-roma "ちゃう")))
-  ;; test はんのう
-  (cl-assert (equal "han'nou" (romkan-to-roma "はんのう"))))
-
-(defun romkan--run-tests ()
-  "Run all the tests."
-  (romkan--test-for-normalize-double-n)
-  (romkan--test-for-hiragana)
-  (romkan--test-for-hepburn)
-  (romkan--test-for-kunrei)
-  (romkan--test-for-roma))
-
-(eval-when-compile
-  (when (not (romkan--run-tests))
-    (message "[Romkan]: all tests were successfully passed!")))
-
 (provide 'romkan)
 ;;; romkan.el ends here
